-----------------------------------------------------------------------------------------------
-- Client Lua Script for BetterRaidFrame
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- BetterRaidFrame Module Definition
-----------------------------------------------------------------------------------------------
local BetterRaidFrame = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
local defaultSettings = {
	raidFramePosition = {10, 10, 260, 95},
}

local userSettings = {
	raidFramePosition = defaultSettings.raidFramePosition,
}
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function BetterRaidFrame:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function BetterRaidFrame:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		"RaidFrameBase",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 
-----------------------------------------------------------------------------------------------
-- Save and Restore
-----------------------------------------------------------------------------------------------
function BetterRaidFrame:OnSave(eType)
	if eType ~= GameLib.CodeEnumAddonSaveLevel.Account then
		return
	end
		
	self:SaveFramePosition(userSettings.raidFramePosition)
	
	return userSettings
	
end

function BetterRaidFrame:OnRestore(eType, tSave)
	if eType ~= GameLib.CodeEnumAddonSaveLevel.Account then
		return
	end
		
	if tSave then
		for k,v in pairs(tSave) do
			userSettings[k] = v
		end
	end
		
	if tSave.raidFramePosition then
		for k,v in pairs(tSave.raidFramePosition) do
			userSettings.raidFramePosition[k] = v
		end
	end
	
end

-----------------------------------------------------------------------------------------------
-- BetterRaidFrame OnLoad
-----------------------------------------------------------------------------------------------
function BetterRaidFrame:OnLoad()

	self:InitializeHook()
	
	Apollo.RegisterSlashCommand("brf", "OnSlashCommand", self)
	
    self.loadTimer = ApolloTimer.Create(0.100, true, "OnLoadTimer", self)

end

function BetterRaidFrame:InitializeHook()
	crbRaidFrame = Apollo.GetAddon("RaidFrameBase")
end

-----------------------------------------------------------------------------------------------
-- BetterRaidFrame Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- on SlashCommand "/brf"
function BetterRaidFrame:OnSlashCommand(strCmd, strParam)
	if strParam ~= "" then
		if strParam == "default" then
			self:LoadFramePosition(defaultSettings.raidFramePosition)
		end
	end
end

function BetterRaidFrame:SaveFramePosition(tPosition)
	tPosition[1], tPosition[2], tPosition[3], tPosition[4] = crbRaidFrame.wndMain:GetAnchorOffsets()
end

function BetterRaidFrame:LoadFramePosition(tPosition)
	crbRaidFrame.wndMain:SetAnchorOffsets(tPosition[1], tPosition[2], tPosition[3], tPosition[4])
end

function BetterRaidFrame:SetupSettings()
	
	if crbRaidFrame.wndMain then
		self.loadTimer:Stop()
		self:LoadFramePosition(userSettings.raidFramePosition)
	end
end

function BetterRaidFrame:OnLoadTimer()
	self:SetupSettings()
end

-----------------------------------------------------------------------------------------------
-- BetterRaidFrame Instance
-----------------------------------------------------------------------------------------------
local BetterRaidFrameInst = BetterRaidFrame:new()
BetterRaidFrameInst:Init()
